blosc2.Codec
============

.. currentmodule:: blosc2

.. autoclass:: Codec
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Codec.BLOSCLZ
      ~Codec.LZ4
      ~Codec.LZ4HC
      ~Codec.ZLIB
      ~Codec.ZSTD
      ~Codec.NDLZ
      ~Codec.ZFP_ACC
      ~Codec.ZFP_PREC
      ~Codec.ZFP_RATE
      ~Codec.OPENHTJ2K
   
   